*---------------------------------------------------------------------------------
* Title      : Unbrick Antrisu MS462xx
* Written by : Mike Tubby G8TIC mike@tubby.org
* Date       : 15-Jun-2020
* Description: Copy known good data back to BBRAM/RTC chip to unbrick MS462xx VNA
*----------------------------------------------------------------------------------

;
; ABSTRACT
;
; This code is designed to copy a known good/woring BBRAM/RTC data block back in to
; an Antrisu MS462xx Vechot Network Analyser after it has become 'bricked' because
; the STM M48T18 BBRAM/RTC chip's battery went flat.
;
; Steps to recover instrument:
;
; 1. Replace the 'Snap Hat' battery
;
; 2. Remove the 27C040 boot prom from U75
;
; 3. Compile this code and program into a 27C040 OTP PLCC prom
;
; 4. Install this PROM in U75
;
; 5. Switch on the instrument
;
; 6. Wait ten seconds
;
; 7. Switch off the instructment
;
; 8. Re-fit the original antrisu boot PROM
;
; Load the debugger and reset the serial number, MAC address and anything else you need.
;


;
; Real values for an instrument
;
ROMBASE EQU $FF800000              ; Where the EPROM appears in the memory map
BBRAM   EQU $FFFC0000              ; Where the BBRAM/RTC device is in the memory map

;
; Test values in Easy68K simulator
;
;ROMBASE EQU $00000000              ; Where the EPROM appears in the memory map
;BBRAM   EQU $00100000              ; Where the BBRAM/RTC device is in the memory map



;
; Start of ROM : 68K Vector table
;
    ORG $0000
    
    DC.L    $FFE7FFFC              ; Stack Pointer
    DC.L    $FF800008              ; Reset/Start
    
    ORG $0008
    MOVE.W  #$2700,SR              ; Status Register = $2700
    JMP ROMBASE+START

;
; End of Vectors
;



;
; Copyright Message
;
    ORG    $0400                     ; Message after vectors

MESSAGE:
    DC.B    'Anritsu Unbrick V1.00 for MS462xx Vector Network Analysers', 0
    DC.B    'Copyright (C) 2020 by Mike Tubby G8TIC mike@tubby.org', 0
    DC.B    'This sofware is Free Software and is provided "as is" and', 0
    DC.B    'without any form of warranty of any type as permitted by Law.', 0


;
; Code starts
;
    ORG    $0800
    
START:
    LEA     ROMBASE+DATA_START,A0   ; Load A0 with pointer BBRAM data in ROM
    LEA     BBRAM,A1                ; Load A1 with pointer to BBRAM chip/device
    MOVE.W  DATA_END-DATA_START,D0  ; Size of memory to be copied

;
; Copy:
;   A0 - source
;   A1 - destination
;   D0 - size in bytes
;
COPY:
    MOVE.B  (A0)+,(A1)+             ; copy indirect one byte, increment src and dst
    DBRA    D0,COPY                 ; loop until done
  
    
;    SIMHALT                         ; halt simulator
    STOP    #$2700


;
; BBRAM_DATA: Our copy of BBRAM data from a good instrument
;
    ORG     $2000
DATA_START:
    INCBIN  MS4622B_OK.BIN
DATA_END:


;
; End of code
;
    END    START        ; last line of source




*~Font name~Courier New~
*~Font size~10~
*~Tab type~1~
*~Tab size~4~
